NoInternetController class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connectionUpdate({required ConnectivityResult result}) → void
internetStateChange() Stream<bool>
listen() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
tryAgain() → void
updateInternet({required bool status}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NoInternetController
no setter